//! Platform-specific extensions for Windows.

cfg_std! {
    pub mod io;
}
